/******************************************************************************
License: Zlib
Copyright:
	(C) 2008 - 2021 Alexander Shaduri <ashaduri@gmail.com>
******************************************************************************/
/// \file
/// \author Alexander Shaduri
/// \ingroup libdebug
/// \weakgroup libdebug
/// @{

#ifndef LIBDEBUG_LIBDEBUG_MINI_H
#define LIBDEBUG_LIBDEBUG_MINI_H


/**
\file
You may include this instead of libdebug.h if you only need the output
functions and not control functions. This may speed up compilation
times because it avoids many dependencies.
\see libdebug.h
*/



// output-related files only
#include "dflags.h"
#include "dout.h"



#endif

/// @}
